from distutils.core import setup

setup(
        name            = 'enthyp_nester',
        version         = '1.2.0',
        py_modules      = ['enthyp_nester'],
        author          = '',
        author_email    = 'babongoo@bongbong.com',
        url             = 'http://www.babongo_much.com',
        description     = 'A simple printer of nested lists'
    )
